@@ -30,7 +30,6 @@ import os
 # import re
 import tempfile
 
-import six
 from sqlalchemy import orm
 
 from rattail.util import load_object
@@ -140,19 +139,13 @@ class AppHandler(object):
         number is *not* considered valid, this method should return the reason
         as string.  If the number is valid, returns ``None``.
         """
-        from rattail.db.util import normalize_phone_number, validate_phone_number
+        from rattail.db.util import normalize_phone_number
 
         # strip non-numeric chars, and make sure we have 10 left
         normal = normalize_phone_number(number)
         if len(normal) != 10:
             return "Phone number must have 10 digits"
 
-        # run it through the "traditional" validation, from FormEncode
-        try:
-            number = validate_phone_number(number, error=True)
-        except Exception as error:
-            return six.text_type(error)
-
     def render_currency(self, value, scale=2, **kwargs):
         """
         Must return a human-friendly display string for the given currency
@@ -165,6 +158,14 @@ class AppHandler(object):
             fmt = "${{:0,.{}f}}".format(scale)
             return fmt.format(value)
 
+    def render_date(self, value, **kwargs):
+        """
+        Must return a human-friendly display string for the given ``date``
+        object.
+        """
+        if value is not None:
+            return value.strftime('%Y-%m-%d')
+
     def render_datetime(self, value, **kwargs):
         """
         Must return a human-friendly display string for the given ``datetime``
