@@ -66,6 +66,7 @@ class BatchHandler(object):
     def __init__(self, config):
         self.config = config
         self.enum = config.get_enum()
+        self.model = config.get_model()
 
     @property
     def batch_model_class(self):
@@ -310,7 +311,8 @@ class BatchHandler(object):
         Returns the data folder specific to the given batch, creating if necessary.
         """
         datadir = self.datadir(batch)
-        os.makedirs(datadir)
+        if not os.path.exists(datadir):
+            os.makedirs(datadir)
         return datadir
 
     # TODO: remove default attr?
