@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2021 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -46,6 +46,7 @@ class DataSyncConsumer(object):
         self.dbkey = dbkey
         self.runas_username = runas
         self.watcher = watcher
+        self.model = config.get_model()
 
     def setup(self):
         """
@@ -241,6 +242,17 @@ class NewDataSyncImportConsumer(DataSyncConsumer):
         return importer.get_local_object(key)
 
 
+class FromRattailConsumer(NewDataSyncImportConsumer):
+    """
+    Base class for consumers which get their data from Rattail.
+    """
+
+    def get_host_object(self, session, change):
+        model = self.model
+        return session.query(getattr(model, change.payload_type))\
+                      .get(change.payload_key)
+
+
 class NullTestConsumer(DataSyncConsumer):
     """
     Consumer which simply does ignores changes, letting DataSync think they
