@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2018 Lance Edgar
+#  Copyright © 2010-2020 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -39,7 +39,19 @@ class DataSyncWatcher(object):
     retry_attempts = 1
     retry_delay = 1 # seconds
 
-    def __init__(self, config, key, dbkey=None):
+    def __init__(self, config, key, dbkey=None, **kwargs):
+        """
+        Constructor.
+
+        Note that while arbitrary kwargs are allowed, the default constructor
+        method does *not* process these in any way.  So if you need to accept
+        some kwargs then you must also define the processing thereof.
+
+        The primary reason for this is because these kwargs, if present, will
+        *always* be simple strings due to how they are read from config.
+        Therefore the burden is on each custom watcher, to interpret them as
+        whatever data type is necessary.
+        """
         self.config = config
         self.key = key
         self.dbkey = dbkey
