@@ -148,6 +148,13 @@ class ContactMixin(object):
     _contact_phone_model = None
     _contact_address_model = None
 
+    def first_email(self, **kwargs):
+        """
+        Return the first available email record for the contact.
+        """
+        if self.emails:
+            return self.emails[0]
+
     def make_email(self, **kwargs):
         """
         Make a new "email" record for the contact.
@@ -198,6 +205,13 @@ class ContactMixin(object):
             session = orm.object_session(self)
             session.flush()
 
+    def first_phone(self, **kwargs):
+        """
+        Return the first available phone record for the contact.
+        """
+        if self.phones:
+            return self.phones[0]
+
     def make_phone(self, **kwargs):
         """
         Make a new "phone" record for the contact.
@@ -250,6 +264,13 @@ class ContactMixin(object):
             if flush:
                 session.flush()
 
+    def first_address(self, **kwargs):
+        """
+        Return the first available address record for the contact.
+        """
+        if self.addresses:
+            return self.addresses[0]
+
     def make_address(self, **kwargs):
         """
         Make a new "address" record for the contact.
