@@ -173,7 +173,7 @@ class FromRattailToRattailImport(FromRattailToRattailBase, FromRattailHandler, T
        Value is ``'import'`` - see also
        :attr:`rattail.importing.handlers.ImportHandler.direction`.
     """
-    dbkey = 'host'
+    dbkey = 'other'
 
     @property
     def host_title(self):
@@ -197,6 +197,7 @@ class FromRattailToRattailExport(FromRattailToRattailBase, FromRattailHandler, T
        :attr:`rattail.importing.handlers.ImportHandler.direction`.
     """
     direction = 'export'
+    dbkey = 'other'
 
     @property
     def host_title(self):
@@ -409,9 +410,17 @@ class ProductWithPriceImporter(FromRattail, model.ProductImporter):
     Note that this importer is not (yet?) used directly, but is
     primarily useful as a base class.
     """
+    # these require special handling due to the 2-way table dependency
+    price_reference_fields = [
+        'regular_price_uuid',
+        'tpr_price_uuid',
+        'sale_price_uuid',
+        'current_price_uuid',
+        'suggested_price_uuid',
+    ]
 
     def query(self):
-        query = super(ProductImporter, self).query()
+        query = super(ProductWithPriceImporter, self).query()
 
         # make sure potential unit items (i.e. rows with NULL unit_uuid) come
         # first, so they will be created before pack items reference them
@@ -430,14 +439,7 @@ class ProductPriceAssociationImporter(ProductWithPriceImporter):
 
     @property
     def simple_fields(self):
-        return [
-            'uuid',
-            'regular_price_uuid',
-            'tpr_price_uuid',
-            'sale_price_uuid',
-            'current_price_uuid',
-            'suggested_price_uuid',
-        ]
+        return ['uuid'] + self.price_reference_fields
 
 
 class ProductImporter(ProductWithPriceImporter):
@@ -454,11 +456,8 @@ class ProductImporter(ProductWithPriceImporter):
         # self-referencing foreign key situation.  an importer can still
         # "support" these fields, but they're excluded from the simple set for
         # sake of rattail <-> rattail
-        fields.remove('regular_price_uuid')
-        fields.remove('tpr_price_uuid')
-        fields.remove('sale_price_uuid')
-        fields.remove('current_price_uuid')
-        fields.remove('suggested_price_uuid')
+        for field in self.price_reference_fields:
+            fields.remove(field)
         return fields
 
 
