@@ -396,10 +396,10 @@ class Email(object):
             prefix = "[STAGE] {}".format(prefix)
         return prefix
 
-    def get_default_subject(self):
+    def get_default_subject(self, **data):
         return self.default_subject
 
-    def get_subject_template(self):
+    def get_subject_template(self, **data):
         """
         Returns the template to be used to build the subject.
         """
@@ -409,7 +409,7 @@ class Email(object):
             return template
 
         # or if this email defines a custom default, use that
-        default = self.get_default_subject()
+        default = self.get_default_subject(**data)
         if default != self.universal_subject:
             return default
 
@@ -425,7 +425,7 @@ class Email(object):
         :rtype: str
         """
         if template is UNSPECIFIED:
-            template = self.get_subject_template()
+            template = self.get_subject_template(**data)
         if template and render:
             return Template(template).render(**data)
         return template
