@@ -68,6 +68,18 @@ class PeopleHandler(GenericHandler):
             person.display_name = self.normalize_full_name(
                 person.first_name, person.last_name)
 
+    def ensure_address(self, person, **kwargs):
+        """
+        Returns the default address record associated with the given
+        person, creating it first if necessary.
+        """
+        address = person.first_address()
+        if not address:
+            address = person.add_address(**kwargs)
+            # TODO: this might be a good idea..maybe if a kwarg flag is set?
+            # person.set_primary_address(address)
+        return address
+
 
 def get_people_handler(config, **kwargs):
     """
