@@ -168,6 +168,26 @@ def previous_month(date, months=1):
     return current.replace(month=current.month - months)
 
 
+def months_ago(date, months):
+    """
+    Returns the "equivalent" day from a previous month.  This refers to the day
+    number within the month, so e.g. if ``date`` is 2021-02-13 and ``months``
+    is 3 then it should return 2020-11-13.
+
+    Note that this is not always strictly possible, for instance if ``date`` is
+    2021-03-31 and ``months`` is 1 then it "should" return 2021-02-31 which is
+    of course not valid.  So in this case it will find the "greatest" day
+    number which is valid, and return that, e.g. 2021-02-28.
+    """
+    month = previous_month(date, months)
+    day = date.day
+    while True:
+        try:
+            return month.replace(day=day)
+        except ValueError:
+            day -= 1
+
+
 def first_of_month(date):
     """
     Returns a date representing the first day of whichever month ``date`` falls in.
